@@ -25,7 +25,7 @@ use crate::protos::*;
 use crate::Channel;
 use crate::IndexFiles;
 
-pub type RelationsReaderPointer = Arc<dyn RelationsReader>;
+pub type RelationsReaderPointer = Arc<RwLock<dyn RelationsReader>>;
 pub type RelationsWriterPointer = Arc<RwLock<dyn RelationsWriter>>;
 pub type ProtosRequest = RelationSearchRequest;
 pub type ProtosResponse = RelationSearchResponse;
@@ -40,7 +40,6 @@ pub trait RelationsReader: std::fmt::Debug + Send + Sync {
     fn search(&self, request: &ProtosRequest) -> NodeResult<ProtosResponse>;
     fn stored_ids(&self) -> NodeResult<Vec<String>>;
     fn get_edges(&self) -> NodeResult<EdgeList>;
-    fn get_node_types(&self) -> NodeResult<TypeList>;
     fn count(&self) -> NodeResult<usize>;
 }
 
