@@ -85,8 +85,8 @@ async fn main() -> NodeResult<()> {
         std::fs::create_dir(data_path.clone())?;
     }
 
-    // XXX it probably should be moved to a more clear abstraction
     lifecycle::initialize_writer(settings.clone())?;
+
     let node_metadata = NodeMetadata::new(settings.clone()).await?;
     let (metadata_sender, metadata_receiver) = tokio::sync::mpsc::unbounded_channel();
 
@@ -98,6 +98,8 @@ async fn main() -> NodeResult<()> {
     let (shutdown_notifier, shutdown_notified) = get_shutdown_notifier();
     let shard_cache = Arc::new(ShardWriterCache::new(settings.clone()));
 
+    lifecycle::initialize_merger(Arc::clone(&shard_cache), settings.clone())?;
+
     let mut replication_task = None;
     if settings.node_role() == NodeRole::Secondary {
         // when it's a secondary server, do not even run the writer GRPC service
@@ -157,6 +159,7 @@ async fn wait_for_sigkill(shutdown_notifier: Arc<Notify>) -> NodeResult<()> {
     }
 
     shutdown_notifier.notify_waiters();
+    lifecycle::finalize_merger();
 
     Ok(())
 }
