@@ -54,9 +54,7 @@ pub mod env {
                 builder.data_path(data_path);
             }
 
-            if let Ok(Ok(max_shards)) =
-                std::env::var("MAX_NODE_REPLICAS").map(|v| v.parse::<usize>())
-            {
+            if let Ok(Ok(max_shards)) = std::env::var("MAX_NODE_REPLICAS").map(|v| v.parse::<usize>()) {
                 builder.max_shards_per_node(max_shards);
             }
 
