@@ -449,8 +449,8 @@ impl ShardWriter {
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn merge(&self) -> NodeResult<MergeMetrics> {
-        let result = write_rw_lock(&self.vector_writer).merge();
+    pub fn merge(&self, context: MergeContext) -> NodeResult<MergeMetrics> {
+        let result = write_rw_lock(&self.vector_writer).merge(context);
         self.metadata.new_generation_id();
 
         result
