@@ -326,6 +326,20 @@ pub struct Sentence {
     pub key: ::prost::alloc::string::String,
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
+pub struct PageInformation {
+    #[prost(uint32, tag="1")]
+    pub page: u32,
+    #[prost(bool, tag="2")]
+    pub page_with_visual: bool,
+}
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct Representation {
+    #[prost(bool, tag="1")]
+    pub is_a_table: bool,
+    #[prost(string, tag="2")]
+    pub reference_file: ::prost::alloc::string::String,
+}
+#[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Paragraph {
     #[prost(uint32, tag="1")]
     pub start: u32,
@@ -346,6 +360,10 @@ pub struct Paragraph {
     /// Optional, as a computed value
     #[prost(string, tag="9")]
     pub text: ::prost::alloc::string::String,
+    #[prost(message, optional, tag="10")]
+    pub page: ::core::option::Option<PageInformation>,
+    #[prost(message, optional, tag="11")]
+    pub representation: ::core::option::Option<Representation>,
 }
 /// Nested message and enum types in `Paragraph`.
 pub mod paragraph {
@@ -681,6 +699,8 @@ pub struct FieldLink {
     pub language: ::prost::alloc::string::String,
     #[prost(map="string, string", tag="6")]
     pub localstorage: ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
+    #[prost(string, tag="7")]
+    pub css_selector: ::prost::alloc::string::String,
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Keyword {
@@ -711,8 +731,6 @@ pub struct FieldFile {
     pub url: ::prost::alloc::string::String,
     #[prost(map="string, string", tag="6")]
     pub headers: ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
-    #[prost(map="string, string", tag="7")]
-    pub cookies: ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Entity {
