@@ -18,9 +18,12 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
-mod merge_worker;
-mod merger;
 mod state;
+use nucliadb_core::fs_state::{self, ELock, Lock, SLock, Version};
+use nucliadb_core::tracing::*;
+use nucliadb_core::Channel;
+use serde::{Deserialize, Serialize};
+use state::*;
 use std::collections::HashSet;
 use std::fs::File;
 use std::io::{BufReader, BufWriter, Write};
@@ -29,26 +32,15 @@ use std::path::{Path, PathBuf};
 use std::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard};
 use std::time::SystemTime;
 
-use crossbeam::channel::{self, Receiver};
-pub use merger::Merger;
-use nucliadb_core::fs_state::{self, ELock, Lock, SLock, Version};
-use nucliadb_core::tracing::*;
-use nucliadb_core::Channel;
-use serde::{Deserialize, Serialize};
-use state::*;
-
 pub use crate::data_point::Neighbour;
 use crate::data_point::{DataPoint, DpId, Journal, Similarity};
-use crate::data_point_provider::merge_worker::Worker;
 use crate::formula::Formula;
 use crate::{VectorErr, VectorR};
 pub type TemporalMark = SystemTime;
 
 const METADATA: &str = "metadata.json";
-const ALLOWED_BEFORE_MERGE: usize = 5;
-
-const MAX_NODES_PER_SEGMENT_VAR: &str = "MAX_NODES_PER_SEGMENT";
-const MAX_SEGMENTS_MERGE_ON_COMMIT_VAR: &str = "MAX_SEGMENTS_MERGE_ON_COMMIT";
+const MAX_NODES_IN_MERGE: &str = "MAX_NODES_IN_MERGE";
+const SEGMENTS_BEFORE_MERGE: &str = "SEGMENTS_BEFORE_MERGE";
 
 pub trait SearchRequest {
     fn get_query(&self) -> &[f32];
@@ -94,18 +86,10 @@ impl IndexMetadata {
     }
 }
 
-#[derive(Default)]
-enum MergerStatus {
-    #[default]
-    Free,
-    WorkScheduled(Receiver<Journal>),
-}
-
 pub struct Index {
-    max_nodes_per_segment: usize,
-    max_segments_in_merge: usize,
+    max_nodes_in_merge: usize,
+    segments_before_merge: usize,
     metadata: IndexMetadata,
-    merger_status: MergerStatus,
     state: RwLock<State>,
     date: RwLock<Version>,
     pub location: PathBuf,
@@ -158,25 +142,24 @@ impl Index {
             let metadata = IndexMetadata::default();
             metadata.write(path).map(|_| metadata)
         })?;
-        let max_nodes_per_segment: usize = match std::env::var(MAX_NODES_PER_SEGMENT_VAR) {
+        let max_nodes_in_merge: usize = match std::env::var(MAX_NODES_IN_MERGE) {
             Ok(v) => v.parse().unwrap_or(50_000),
             Err(_) => 50_000,
         };
-        let max_segments_in_merge: usize = match std::env::var(MAX_SEGMENTS_MERGE_ON_COMMIT_VAR) {
-            Ok(v) => v.parse().unwrap_or(10),
-            Err(_) => 10,
+        let segments_before_merge: usize = match std::env::var(SEGMENTS_BEFORE_MERGE) {
+            Ok(v) => v.parse().unwrap_or(100),
+            Err(_) => 100,
         };
-        let index = Index {
+
+        Ok(Index {
             metadata,
-            max_nodes_per_segment,
-            max_segments_in_merge,
-            merger_status: MergerStatus::Free,
+            max_nodes_in_merge,
+            segments_before_merge,
             dimension: RwLock::new(dimension_used),
             state: RwLock::new(state),
             date: RwLock::new(date),
             location: path.to_path_buf(),
-        };
-        Ok(index)
+        })
     }
 
     pub fn new(path: &Path, metadata: IndexMetadata) -> VectorR<Index> {
@@ -186,25 +169,24 @@ impl Index {
 
         let state = fs_state::load_state::<State>(path)?;
         let date = fs_state::crnt_version(path)?;
-        let max_nodes_per_segment: usize = match std::env::var(MAX_NODES_PER_SEGMENT_VAR) {
+        let max_nodes_in_merge: usize = match std::env::var(MAX_NODES_IN_MERGE) {
             Ok(v) => v.parse().unwrap_or(50_000),
             Err(_) => 50_000,
         };
-        let max_segments_in_merge: usize = match std::env::var(MAX_SEGMENTS_MERGE_ON_COMMIT_VAR) {
-            Ok(v) => v.parse().unwrap_or(10),
-            Err(_) => 10,
+        let segments_before_merge: usize = match std::env::var(SEGMENTS_BEFORE_MERGE) {
+            Ok(v) => v.parse().unwrap_or(100),
+            Err(_) => 100,
         };
-        let index = Index {
+
+        Ok(Index {
             metadata,
-            max_nodes_per_segment,
-            max_segments_in_merge,
-            merger_status: MergerStatus::Free,
+            max_nodes_in_merge,
+            segments_before_merge,
             dimension: RwLock::new(None),
             state: RwLock::new(state),
             date: RwLock::new(date),
             location: path.to_path_buf(),
-        };
-        Ok(index)
+        })
     }
 
     pub fn delete(&self, prefix: impl AsRef<str>, temporal_mark: SystemTime, _: &Lock) {
@@ -231,21 +213,6 @@ impl Index {
     }
 
     pub fn collect_garbage(&mut self, _lock: &ELock) -> VectorR<()> {
-        // A merge may be waiting to be recorded.
-        let possible_merge = self.take_available_merge_or_wait();
-        let mut state = self.write_state();
-        let mut date = self.write_date();
-        if let Some(journal) = possible_merge {
-            state.replace_work_unit(journal)
-        }
-
-        fs_state::persist_state::<State>(&self.location, &state)?;
-        *date = fs_state::crnt_version(&self.location)?;
-        std::mem::drop(state);
-        std::mem::drop(date);
-
-        // At this point there are no merges available, so we can
-        // start collecting garbage.
         let state = self.read_state();
         let in_use_dp: HashSet<_> = state.dpid_iter().map(|journal| journal.id()).collect();
         for dir_entry in std::fs::read_dir(&self.location)? {
@@ -288,33 +255,47 @@ impl Index {
         Ok(())
     }
 
-    fn take_available_merge_or_wait(&mut self) -> Option<Journal> {
-        let MergerStatus::WorkScheduled(rcv) = std::mem::take(&mut self.merger_status) else {
-            return None;
-        };
-        rcv.recv().ok()
-    }
-
-    fn merge(&self, state: &State, max_nodes_per_segment: usize, capacity: usize) -> VectorR<Merge> {
-        let channel = self.metadata.channel;
+    fn merge(&self, state: &State, max_nodes_in_merge: usize) -> VectorR<Option<Merge>> {
         let location = self.location.clone();
         let similarity = self.metadata.similarity;
         let mut live_segments: Vec<_> = state.dpid_iter().collect();
         let mut blocked_segments = vec![];
-        let mut buffer = Vec::with_capacity(capacity);
+        let mut nodes_in_merge = 0;
+        let mut buffer = Vec::new();
+        let mut live_segments_are_sorted = false;
 
-        while buffer.len() < capacity {
+        if live_segments.len() < self.segments_before_merge {
+            return Ok(None);
+        }
+
+        if live_segments.len() < 1000 {
+            // Order smallest segments last (first to be pop()), so they are merged first
+            live_segments.sort_unstable_by_key(|i| std::cmp::Reverse(i.no_nodes()));
+            live_segments_are_sorted = true;
+        }
+
+        while nodes_in_merge < max_nodes_in_merge {
             let Some(journal) = live_segments.pop() else {
                 break;
             };
-            if journal.no_nodes() >= max_nodes_per_segment {
+            if nodes_in_merge + journal.no_nodes() > max_nodes_in_merge {
                 blocked_segments.push(journal);
-            } else {
-                buffer.push((state.delete_log(journal), journal.id()));
+                if live_segments_are_sorted {
+                    break;
+                } else {
+                    continue;
+                }
             }
+
+            nodes_in_merge += journal.no_nodes();
+            buffer.push((state.delete_log(journal), journal.id()));
         }
 
-        let new_dp = DataPoint::merge(&location, &buffer, similarity, channel)?;
+        if buffer.len() < 2 {
+            return Ok(None);
+        }
+
+        let new_dp = DataPoint::merge(&location, &buffer, similarity)?;
         blocked_segments.push(new_dp.journal());
         blocked_segments.extend(live_segments);
         let live_segments = blocked_segments;
@@ -328,68 +309,39 @@ impl Index {
             new_data_points: live_segments,
         };
 
-        Ok(merge)
+        Ok(Some(merge))
     }
 
     /// Returns the number of segments that have been merged.
     pub fn force_merge(&mut self, _lock: &Lock) -> VectorR<MergeMetrics> {
-        let possible_merge = self.take_available_merge_or_wait();
         let mut state = self.write_state();
         let mut date = self.write_date();
+        let mut metrics = MergeMetrics {
+            merged: 0,
+            segments_left: state.work_stack_len(),
+        };
 
-        if let Some(journal) = possible_merge {
-            state.replace_work_unit(journal);
-        }
-
-        if state.work_stack_len() <= 1 {
-            return Ok(MergeMetrics {
-                merged: 0,
-                segments_left: state.work_stack_len(),
-            });
-        }
-
-        let merge = self.merge(&state, 50_000, 100)?;
-        let live_segments = merge.new_data_points;
-        let metrics = merge.metrics;
-
-        state.rebuilt_work_stack_with(live_segments);
-        fs_state::persist_state::<State>(&self.location, &state)?;
-        *date = fs_state::crnt_version(&self.location)?;
+        if let Some(merge) = self.merge(&state, 50_000)? {
+            metrics = merge.metrics;
+            state.rebuilt_work_stack_with(merge.new_data_points);
+            fs_state::persist_state::<State>(&self.location, &state)?;
+            *date = fs_state::crnt_version(&self.location)?;
+        };
 
         Ok(metrics)
     }
 
     pub fn commit(&mut self, _lock: &Lock) -> VectorR<()> {
-        let possible_merge = self.take_available_merge_or_wait();
         let mut state = self.write_state();
         let mut date = self.write_date();
 
-        if let Some(journal) = possible_merge {
-            state.replace_work_unit(journal);
-        }
-
-        if state.work_stack_len() > 1 {
-            let max_nodes_per_segment = self.max_nodes_per_segment;
-            let max_segments_in_merge = self.max_segments_in_merge;
-            let merge = self.merge(&state, max_nodes_per_segment, max_segments_in_merge)?;
+        if let Some(merge) = self.merge(&state, self.max_nodes_in_merge)? {
             let data_points = merge.new_data_points;
             state.rebuilt_work_stack_with(data_points);
         }
 
         fs_state::persist_state::<State>(&self.location, &state)?;
         *date = fs_state::crnt_version(&self.location)?;
-        let work_stack_len = state.work_stack_len();
-        std::mem::drop(state);
-        std::mem::drop(date);
-
-        if work_stack_len > ALLOWED_BEFORE_MERGE {
-            let location = self.location.clone();
-            let similarity = self.metadata.similarity;
-            let (sender, receiver) = channel::unbounded();
-            let worker = Worker::request(location, sender, similarity, self.metadata.channel);
-            self.merger_status = MergerStatus::WorkScheduled(receiver);
-            merger::send_merge_request(worker);
-        }
         Ok(())
     }
     pub fn try_elock(&self) -> VectorR<ELock> {
@@ -422,31 +374,6 @@ mod test {
     use super::*;
     use crate::data_point::{Elem, LabelDictionary, Similarity};
 
-    #[test]
-    fn force_merge_more_than_limit() -> NodeResult<()> {
-        let dir = tempfile::tempdir()?;
-        let vectors_path = dir.path().join("vectors");
-        let mut index = Index::new(&vectors_path, IndexMetadata::default())?;
-        let lock = index.get_elock()?;
-
-        let mut journals = vec![];
-        for _ in 0..200 {
-            let similarity = Similarity::Cosine;
-            let channel = Channel::EXPERIMENTAL;
-            let embeddings = vec![];
-            let time = Some(SystemTime::now());
-            let data_point = DataPoint::new(&vectors_path, embeddings, time, similarity, channel).unwrap();
-            journals.push(data_point.journal());
-        }
-
-        index.write_state().rebuilt_work_stack_with(journals);
-
-        let metrics = index.force_merge(&lock).unwrap();
-        assert_eq!(metrics.merged, 100);
-        assert_eq!(metrics.segments_left, 101);
-        Ok(())
-    }
-
     #[test]
     fn force_merge_less_than_limit() -> NodeResult<()> {
         let dir = tempfile::tempdir()?;
@@ -454,13 +381,14 @@ mod test {
         let mut index = Index::new(&vectors_path, IndexMetadata::default())?;
         let lock = index.get_elock()?;
 
+        index.segments_before_merge = 5;
+
         let mut journals = vec![];
         for _ in 0..50 {
             let similarity = Similarity::Cosine;
-            let channel = Channel::EXPERIMENTAL;
             let embeddings = vec![];
             let time = Some(SystemTime::now());
-            let data_point = DataPoint::new(&vectors_path, embeddings, time, similarity, channel).unwrap();
+            let data_point = DataPoint::new(&vectors_path, embeddings, time, similarity).unwrap();
             journals.push(data_point.journal());
         }
 
@@ -482,10 +410,9 @@ mod test {
         let mut journals = vec![];
         for _ in 0..100 {
             let similarity = Similarity::Cosine;
-            let channel = Channel::EXPERIMENTAL;
             let embeddings = vec![];
             let time = Some(SystemTime::now());
-            let data_point = DataPoint::new(&vectors_path, embeddings, time, similarity, channel).unwrap();
+            let data_point = DataPoint::new(&vectors_path, embeddings, time, similarity).unwrap();
             journals.push(data_point.journal());
         }
 
@@ -511,7 +438,7 @@ mod test {
 
         let empty_no_entries = std::fs::read_dir(&vectors_path)?.count();
         for _ in 0..10 {
-            DataPoint::new(&vectors_path, vec![], None, Similarity::Cosine, Channel::EXPERIMENTAL).unwrap();
+            DataPoint::new(&vectors_path, vec![], None, Similarity::Cosine).unwrap();
         }
 
         index.collect_garbage(&lock)?;
@@ -535,7 +462,6 @@ mod test {
             ],
             None,
             Similarity::Cosine,
-            Channel::EXPERIMENTAL,
         )
         .unwrap();
         index.add(data_point, &lock).unwrap();
